@@ -1,7 +1,7 @@
 package App::lcpan::Call;
 
-our $DATE = '2016-02-16'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2016-10-01'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -20,7 +20,6 @@ $SPEC{call_lcpan_script} = {
         max_age => {
             summary => 'Maximum index age (in seconds)',
             schema => 'duration',
-            'x.perl.coerce_to' => 'int(secs)',
             description => <<'_',
 
 If unspecified, will look at `LCPAN_MAX_AGE` environment variable. If that is
@@ -82,7 +81,7 @@ App::lcpan::Call - "Call" lcpan script
 
 =head1 VERSION
 
-This document describes version 0.08 of App::lcpan::Call (from Perl distribution App-lcpan-Call), released on 2016-02-16.
+This document describes version 0.09 of App::lcpan::Call (from Perl distribution App-lcpan-Call), released on 2016-10-01.
 
 =head1 FUNCTIONS
 
@@ -119,6 +118,12 @@ that contains extra information.
 
 Return value:  (any)
 
+=head1 ENVIRONMENT
+
+=head2 LCPAN_MAX_AGE => int
+
+Set the default of C<max_age>.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/App-lcpan-Call>.
